===============
Getting Started
===============

Materialism is an HTML theme for the Sphinx documentation generator.

Installation
------------

.. code-block::

    pip install materialism

Lorem ipsum dolor sit amet consectetur adipisicing elit. Eum sapiente tenetur nihil reiciendis perspiciatis quas ipsa ipsam, provident fugiat quaerat laboriosam numquam hic inventore dignissimos? Inventore earum culpa deleniti voluptatibus.

Lorem ipsum dolor sit amet consectetur adipisicing elit. Eum sapiente tenetur nihil reiciendis perspiciatis quas ipsa ipsam, provident fugiat quaerat laboriosam numquam hic inventore dignissimos? Inventore earum culpa deleniti voluptatibus.

Dolor sit
---------

Lorem ipsum dolor sit amet consectetur adipisicing elit. Eum sapiente tenetur nihil reiciendis perspiciatis quas ipsa ipsam, provident fugiat quaerat laboriosam numquam hic inventore dignissimos? Inventore earum culpa deleniti voluptatibus.
